ESO Science Archive - Data Products

GENERIC | SPECTRAL | IMAGING | VISTA
PHASE3 ARCHIVE INTERFACES
HELP | REDUCED DATA TYPES DESCRIPTION | FAQ | DATA RELEASES
| Generic Data Products Query Form

Please be aware of an important announcement about the flux calibration of XSHOOTER UVB data products.
This form provides access to reduced or fully calibrated data sets, and derived catalogs, that were contributed by PIs of ESO programmes or produced by ESO (using ESO calibration pipelines with the best available calibration data), and then integrated into the ESO Science Archive Facility starting April 2011, through the Phase 3 process. Included are optical, infrared, and APEX (millimetre, submillimetre) data products. Each available data set is fully described; please see the list of contributed data releases and pipeline-processed data streams including their corresponding descriptions. This form allows generic query constraints for all types of data products. More specific forms, customised for each particular data type, are available for optical and infrared imaging, for spectra, and for VISTA data products. Other data not yet migrated to the Phase 3 infrastructure are available via different user interfaces; please check the archive home page.

Note: The FITS format of the spectra retrievable via this query form complies to the ESO Science Data Product standard [PDF]. The 1d spectra help page provides a list of tools that support this format and a quick guide to read and display these spectra in IDL and IRAF.

Target/Position Information

| Target name |  |  |  | Query by Target List: |
| Input Coord. Sys. |
| Position RA | DEC |  | RA: sexagesimal hours, decimal degrees
| Search Box |  | Output Display: |
| RA |  | DEC |  | Gal long |  | Gal lat

Bandpass/Wavelength and Product Category

| Filter |  |  | OR |  | Wavelength | [nm] E.g.: 656, 393 AND 656, 393..656

| Product category |
| Any | catalog | cube | image | source_table | spectrum

Observation/Temporal Parameters

| Telescope |  |  |  | Instrument |  |  |  | OBSTECH |

| Date Obs |  | UT time (Place the mouse here to see examples)
| MJD Obs | Modified Julian Date
| Exptime | Total integration time per pixel [s]
| Multi OB |

Collections and Observing Programmes

| Collection |

| Run/Program ID | eg 179.B-2003(B) |  | PI Name |  |  | Certified by |

Submission, Proprietary Period & Bibliographic Information

| ORIGFILE |  |  | ARCFILE |
| Release Date |  |  | REFERENC | bibcode
| Batch Id |  |  | Publication Date |

Query by raw data

| Raw Data File List |

Sorting

| Sort results by |

Extra Columns on Tabular Output

Use tabular output even if only one row is returned.
Use full-screen output even if more than one row is returned.

ESO HOME | ARCHIVE HOME | ARCHIVE FAQ
wdb 3.0g - 21-SEP-2016 ...... Send comments to archive@eso.org